@@ -33,7 +33,7 @@
  *      All the public types and function declarations for the core
  *	AOLserver.
  *
- *	$Header: /cvs/root/aolserver/aolserver/aolserver/include/ns.h,v 1.55.2.3 2004/06/03 18:28:02 rcrittenden0569 Exp $
+ *	$Header: /cvsroot/aolserver/aolserver/include/ns.h,v 1.55.2.15 2004/11/22 20:43:04 dossy Exp $
  */
 
 #ifndef NS_H
@@ -41,9 +41,9 @@
 
 #define NS_MAJOR_VERSION	4
 #define NS_MINOR_VERSION	0
-#define NS_RELEASE_SERIAL	5
+#define NS_RELEASE_SERIAL	9
 #define NS_VERSION		"4.0"
-#define NS_PATCH_LEVEL		"4.0.5"
+#define NS_PATCH_LEVEL		"4.0.9"
 
 #define NS_ALPHA_RELEASE	0
 #define NS_BETA_RELEASE		1
@@ -107,6 +107,9 @@
 #define NS_SOCK_WRITE		  2
 #define NS_SOCK_EXCEPTION	  4
 #define NS_SOCK_EXIT		  8
+#define NS_SOCK_DROP             16
+#define NS_SOCK_CANCEL           32
+#define NS_SOCK_ANY		255
 #define NS_ENCRYPT_BUFSIZE 	 16
 #define NS_DRIVER_ASYNC		  1	/* Use async read-ahead. */
 #define NS_DRIVER_SSL		  2	/* Use SSL port, protocol defaults. */
@@ -115,7 +118,6 @@
 #if defined(__alpha)
 typedef long			ns_int64;
 typedef unsigned long		ns_uint64;
-typedef long 			INT64;
 #define NS_INT_64_FORMAT_STRING "%ld"
 #elif defined(_WIN32)
 typedef int			mode_t;  /* Bug: #703061 */ 
@@ -533,6 +535,12 @@ NS_EXTERN void Ns_ClsAlloc(Ns_Cls *clsPtr, Ns_Callback *proc);
 NS_EXTERN void *Ns_ClsGet(Ns_Cls *clsPtr, Ns_Conn *conn);
 NS_EXTERN void Ns_ClsSet(Ns_Cls *clsPtr, Ns_Conn *conn, void *data);
 
+/*
+ * compress.c:
+ */
+
+NS_EXTERN int Ns_Compress(char *buf, int len, Tcl_DString *outPtr, int level);
+
 /*
  * config.c:
  */
@@ -1059,6 +1067,7 @@ NS_EXTERN char *Ns_SockStrError(int err);
 
 NS_EXTERN int Ns_SockCallback(SOCKET sock, Ns_SockProc *proc, void *arg, int when);
 NS_EXTERN void Ns_SockCancelCallback(SOCKET sock);
+NS_EXTERN int Ns_SockCancelCallbackEx(SOCKET sock, Ns_SockProc *proc, void *arg);
 
 /*
  * str.c:
