@@ -34,7 +34,7 @@
  *      Handle connection I/O.
  */
 
-static const char *RCSID = "@(#) $Header: /cvs/root/aolserver/aolserver/aolserver/nsd/connio.c,v 1.12 2003/03/07 18:08:17 vasiljevic Exp $, compiled: " __DATE__ " " __TIME__;
+static const char *RCSID = "@(#) $Header: /cvsroot/aolserver/aolserver/nsd/connio.c,v 1.12.2.2 2004/09/17 15:58:19 dossy Exp $, compiled: " __DATE__ " " __TIME__;
 
 #include "nsd.h"
 #define IOBUFSZ 2048
@@ -159,7 +159,7 @@ Ns_ConnSend(Ns_Conn *conn, struct iovec *bufs, int nbufs)
     }
     nbufs = n;
     bufs = sbufs;
-    nwrote = 0;
+    n = nwrote = 0;
     while (towrite > 0) {
 	n = NsSockSend(connPtr->sockPtr, bufs, nbufs);
 	if (n < 0) {
@@ -195,6 +195,12 @@ Ns_ConnSend(Ns_Conn *conn, struct iovec *bufs, int nbufs)
 		nwrote = 0;
 	    }
 	}
+    } else {
+        /*
+         * Return error on first send, if any, from NsSockSend above.
+         */
+
+        nwrote = n;
     }
     return nwrote;
 }
@@ -766,6 +772,14 @@ ConnSend(Ns_Conn *conn, int nsend, Tcl_Channel chan, FILE *fp, int fd)
     int             toread, nread, status;
     char            buf[IOBUFSZ];
 
+    /*
+     * Even if nsend is 0, ensure all queued data (like HTTP response
+     * headers) get flushed.
+     */
+    if (nsend == 0) {
+        Ns_WriteConn(conn, NULL, 0);
+    }
+
     status = NS_OK;
     while (status == NS_OK && nsend > 0) {
         toread = nsend;
@@ -790,5 +804,6 @@ ConnSend(Ns_Conn *conn, int nsend, Tcl_Channel chan, FILE *fp, int fd)
             nsend -= nread;
 	}
     }
+
     return status;
 }
