@@ -58,6 +58,7 @@
 #include <sys/ioctl.h>
 #include <sys/stat.h>
 #include <ctype.h>
+#include <grp.h>
 
 #endif	/* WIN32 */
 
@@ -75,6 +76,9 @@
   extern int poll(struct pollfd *, unsigned long, int);
 #endif
 
+#ifdef __linux
+  #include <sys/prctl.h>
+#endif
 #ifdef __hp
   #define seteuid(i)     setresuid((-1),(i),(-1))
 #endif
@@ -106,7 +110,7 @@
 #define NSD_NAME             "AOLserver"
 #define NSD_VERSION	     NS_PATCH_LEVEL
 #define NSD_LABEL            "aolserver4_0"
-#define NSD_TAG              "$Name: aolserver_v40_r5 $"
+#define NSD_TAG              "$Name: aolserver_v40_r9 $"
 #define NS_CONFIG_PARAMETERS "ns/parameters"
 #define NS_CONFIG_THREADS    "ns/threads"
 
@@ -773,6 +777,7 @@ extern void NsInitConf(void);
 extern void NsInitEncodings(void);
 extern void NsInitListen(void);
 extern void NsInitLog(void);
+extern void NsInitInfo(void);
 extern void NsInitMimeTypes(void);
 extern void NsInitModLoad(void);
 extern void NsInitProcInfo(void);
@@ -859,6 +864,7 @@ extern void NsStartServer(NsServer *servPtr);
 extern void NsStopServer(NsServer *servPtr);
 extern void NsWaitServer(NsServer *servPtr, Ns_Time *toPtr);
 extern void NsStartDrivers(void);
+extern void NsWaitDriversShutdown(Ns_Time *toPtr);
 extern void NsStartSchedShutdown(void);
 extern void NsWaitSchedShutdown(Ns_Time *toPtr);
 extern void NsStartSockShutdown(void); 
